import 'package:flutter_custom_toolbox/flutter_toolbox.dart';

import 'package:jeweled/config/default_activity_settings.dart';

class ActivitySettings {
  final String boardSize;
  final String colorsCount;

  ActivitySettings({
    required this.boardSize,
    required this.colorsCount,
  });

  // Getters to convert String to int
  int get boardSizeValue => int.parse(boardSize);
  int get colorsCountValue => int.parse(colorsCount);

  static String getBoardSizeValueFromUnsafe(String size) {
    if (DefaultActivitySettings.allowedBoardSizeValues.contains(size)) {
      return size;
    }

    return DefaultActivitySettings.defaultBoardSizeValue;
  }

  static String getColorsCountValueFromUnsafe(String colorsCount) {
    if (DefaultActivitySettings.allowedColorsCountValues.contains(colorsCount)) {
      return colorsCount;
    }

    return DefaultActivitySettings.defaultColorsCountValue;
  }

  factory ActivitySettings.createDefault() {
    return ActivitySettings(
      boardSize: DefaultActivitySettings.defaultBoardSizeValue,
      colorsCount: DefaultActivitySettings.defaultColorsCountValue,
    );
  }

  void dump() {
    printlog('$ActivitySettings:');
    printlog('  ${DefaultActivitySettings.parameterCodeBoardSize}: $boardSize');
    printlog('  ${DefaultActivitySettings.parameterCodeColorsCount}: $colorsCount');
    printlog('');
  }

  @override
  String toString() {
    return '$ActivitySettings(${toJson()})';
  }

  Map<String, dynamic>? toJson() {
    return <String, dynamic>{
      DefaultActivitySettings.parameterCodeBoardSize: boardSize,
      DefaultActivitySettings.parameterCodeColorsCount: colorsCount,
    };
  }
}
